@@ -35,6 +35,8 @@
 #' @export
 #' @examples
 #' # Feature selection on Palmer Penguins data set
+#' \donttest{
+#'
 #' task = tsk("penguins")
 #' learner = lrn("classif.rpart")
 #'
@@ -61,6 +63,7 @@
 #'
 #' # Inspect all evaluated sets
 #' as.data.table(instance$archive)
+#' }
 FSelectInstanceSingleCrit = R6Class("FSelectInstanceSingleCrit",
   inherit = OptimInstanceSingleCrit,
   public = list(
@@ -107,6 +110,23 @@ FSelectInstanceSingleCrit = R6Class("FSelectInstanceSingleCrit",
       assert_number(y)
       assert_names(names(y), permutation.of = self$objective$codomain$ids())
       private$.result = cbind(xdt, t(y)) # t(y) so the name of y stays
+    },
+
+    #' @description
+    #' Printer.
+    #'
+    #' @param ... (ignored).
+    print = function(...) {
+      catf(format(self))
+      catf(str_indent("* State: ", if (is.null(private$.result)) "Not optimized" else "Optimized"))
+      catf(str_indent("* Objective:", format(self$objective)))
+      catf(str_indent("* Terminator:", format(self$terminator)))
+      if (!is.null(private$.result)) {
+        catf("* Result:")
+        print(self$result[, c(self$archive$cols_x, self$archive$cols_y), with = FALSE])
+        catf("* Archive:")
+        print(as.data.table(self$archive)[, c(self$archive$cols_x, self$archive$cols_y), with = FALSE])
+      }
     }
   ),
 
