@@ -60,45 +60,45 @@ test_that("ArchiveFSelect as.data.table function works", {
 
   # default
   tab = as.data.table(instance$archive)
-  expect_data_table(tab, nrows = 4, ncols = 13)
+  expect_data_table(tab, nrows = 4, ncols = 15)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "timestamp", "batch_nr", "resample_result"))
+    "runtime_learners", "timestamp", "batch_nr", "warnings", "errors", "resample_result"))
 
   # extra measure
   tab = as.data.table(instance$archive, measures = msr("classif.acc"))
-  expect_data_table(tab, nrows = 4, ncols = 14)
+  expect_data_table(tab, nrows = 4, ncols = 16)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "classif.acc", "runtime_learners", "timestamp", "batch_nr", "resample_result"))
+    "classif.acc", "runtime_learners", "timestamp", "batch_nr",  "warnings", "errors", "resample_result"))
 
   # extra measures
   tab = as.data.table(instance$archive, measures = msrs(c("classif.acc", "classif.mcc")))
-  expect_data_table(tab, nrows = 4, ncols = 15)
+  expect_data_table(tab, nrows = 4, ncols = 17)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "classif.acc", "classif.mcc", "runtime_learners", "timestamp", "batch_nr", "resample_result"))
+    "classif.acc", "classif.mcc", "runtime_learners", "timestamp", "batch_nr", "warnings", "errors", "resample_result"))
 
   # exclude column
   tab = as.data.table(instance$archive, exclude_columns = "timestamp")
-  expect_data_table(tab, nrows = 4, ncols = 13)
+  expect_data_table(tab, nrows = 4, ncols = 15)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "batch_nr", "uhash", "resample_result"))
+    "runtime_learners", "batch_nr", "uhash", "warnings", "errors", "resample_result"))
 
   # exclude columns
   tab = as.data.table(instance$archive, exclude_columns = c("timestamp", "uhash"))
-  expect_data_table(tab, nrows = 4, ncols = 12)
+  expect_data_table(tab, nrows = 4, ncols = 14)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "batch_nr", "resample_result"))
+    "runtime_learners", "batch_nr",  "warnings", "errors", "resample_result"))
 
   # no exclude
   tab = as.data.table(instance$archive, exclude_columns = NULL)
-  expect_data_table(tab, nrows = 4, ncols = 14)
+  expect_data_table(tab, nrows = 4, ncols = 16)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "timestamp", "batch_nr", "uhash", "resample_result"))
+    "runtime_learners", "timestamp", "batch_nr",  "uhash", "warnings", "errors", "resample_result"))
 
   # no unnest
   tab = as.data.table(instance$archive, unnest = NULL)
-  expect_data_table(tab, nrows = 4, ncols = 13)
+  expect_data_table(tab, nrows = 4, ncols = 15)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "timestamp", "batch_nr", "resample_result"))
+    "runtime_learners", "timestamp", "batch_nr",  "warnings", "errors", "resample_result"))
 
   # without benchmark result
   instance = FSelectInstanceSingleCrit$new(
@@ -112,9 +112,9 @@ test_that("ArchiveFSelect as.data.table function works", {
   fselector$optimize(instance)
 
   tab = as.data.table(instance$archive)
-  expect_data_table(tab, nrows = 4, ncols = 12)
+  expect_data_table(tab, nrows = 4, ncols = 14)
   expect_named(tab, c("age", "glucose", "insulin", "mass", "pedigree", "pregnant", "pressure", "triceps", "classif.ce",
-    "runtime_learners", "timestamp", "batch_nr"))
+    "runtime_learners", "timestamp", "batch_nr", "warnings", "errors"))
 
   # empty archive
   instance = FSelectInstanceSingleCrit$new(
