@@ -1,9 +1,7 @@
-context("FSelectInstanceMultiCrit")
-
 test_that("empty FSelectInstanceMultiCrit works", {
   inst = TEST_MAKE_INST_2D()
 
-  expect_data_table(inst$archive$data(), nrows = 0L)
+  expect_data_table(inst$archive$data, nrows = 0L)
   expect_identical(inst$archive$n_evals, 0L)
   expect_identical(inst$archive$n_batch, 0L)
   expect_null(inst$result)
@@ -16,12 +14,12 @@ test_that("eval_batch works", {
     x3 = list(TRUE, TRUE), x4 = list(TRUE, TRUE))
 
   z = inst$eval_batch(xdt)
-  expect_named(z, c("regr.mse", "regr.rmse", "uhash"))
+  expect_named(z, c("regr.mse", "regr.rmse"))
   expect_identical(inst$archive$n_evals, 2L)
   expect_data_table(z, nrows = 2L)
 
   z = inst$eval_batch(xdt)
-  expect_named(z, c("regr.mse", "regr.rmse", "uhash"))
+  expect_named(z, c("regr.mse", "regr.rmse"))
   expect_identical(inst$archive$n_evals, 4L)
   expect_data_table(z, nrows = 2L)
 })
@@ -38,7 +36,7 @@ test_that("store_benchmark_result flag works", {
     x3 = list(TRUE, TRUE), x4 = list(TRUE, TRUE))
   inst$eval_batch(xdt)
 
-  expect_true("uhashes" %nin% colnames(inst$archive$data()))
+  expect_true("uhashes" %nin% colnames(inst$archive$data))
 
   inst = TEST_MAKE_INST_2D(store_benchmark_result = TRUE)
   xdt = data.table(x1 = list(TRUE, FALSE), x2 = list(FALSE, TRUE),
